@@ -13,6 +13,7 @@ from . import pyenchant  # noqa: F401
 from . import pygame  # noqa: F401
 from . import pyopengl  # noqa: F401
 from . import pyside  # noqa: F401
+from . import pyside2  # noqa: F401
 from . import pyzmq  # noqa: F401
 from . import qt5  # noqa: F401
 from . import re  # noqa: F401
@@ -20,6 +21,7 @@ from . import scipy  # noqa: F401
 from . import sip  # noqa: F401
 from . import subprocess  # noqa: F401
 from . import sysconfig_module  # noqa: F401
+from . import tkinter  # noqa: F401
 from . import virtualenv  # noqa: F401
 from . import wx  # noqa: F401
 from . import xml  # noqa: F401
